#
# spec file for package benchmark
#
# Copyright (c) 2021 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%define soname  lib%{name}
%define sover   1
Name:           benchmark
Version:        1.5.5
Release:        bp154.1.64
Summary:        A microbenchmark support library
License:        Apache-2.0
URL:            https://github.com/google/benchmark
Source:         %{name}-%{version}.tar.gz
BuildRequires:  cmake >= 3.5.1
BuildRequires:  gcc-c++
BuildRequires:  git-core
BuildRequires:  gmock
BuildRequires:  gtest
BuildRequires:  pkgconfig

%description
A library to support the benchmarking of functions, similar to unit-tests.

%package -n %{soname}%{sover}
Summary:        Shared library for google benchmark

%description -n %{soname}%{sover}
A library to support the benchmarking of functions, similar to unit-tests.

%package devel
Summary:        Development files for google benchmark
Requires:       %{soname}%{sover} = %{version}

%description devel
Development files for google benchmark library

%prep
%autosetup

%build
sed -e 's|lib_install_dir "lib/"|lib_install_dir "%{_libdir}/"|g' \
    -e 's|config_install_dir "lib/cmake|config_install_dir "%{_libdir}/cmake|g' \
    -e 's|pkgconfig_install_dir "lib/pkgconfig"|pkgconfig_install_dir "%{_libdir}/pkgconfig"|g' \
    -i src/CMakeLists.txt
sed -e 's|libdir=${prefix}/lib|libdir=${prefix}/%{_lib}|' \
    -i cmake/benchmark.pc.in

%cmake \
  -DBENCHMARK_ENABLE_LTO=on \
  -DBENCHMARK_ENABLE_GTEST_TESTS=false \
  -DBENCHMARK_ENABLE_TESTING=true
%cmake_build

%install
%cmake_install
# dont ship debug stuff
rm -rf %{buildroot}%{_libexecdir}/debug

%check
# path needs to be exported otherwise unit tests will fail
export LD_LIBRARY_PATH=$LD_LIBRARY_PATH:%{_builddir}/%{name}-%{version}/build/src/
%ctest

%post -n %{soname}%{sover} -p /sbin/ldconfig
%postun -n %{soname}%{sover} -p /sbin/ldconfig

%files -n %{soname}%{sover}
%license LICENSE
%doc README.md AUTHORS
%{_libdir}/%{soname}.so.%{sover}*
%{_libdir}/%{soname}_main.so.%{sover}*

%files devel
%license LICENSE
%doc README.md AUTHORS
%dir %{_libdir}/cmake/%{name}
%{_libdir}/cmake/%{name}/*.cmake
%{_libdir}/pkgconfig/%{name}.pc
%{_libdir}/%{soname}.so
%{_libdir}/%{soname}_main.so
%{_includedir}/%{name}

%changelog
* Mon Sep 13 2021 Martin Pluskal <mpluskal@suse.com>
- Update to version 1.5.5:
  * [NFCI] Drop warning to satisfy clang's -Wunused-but-set-variable diag (#1174)
  * Add support for new architecture loongarch (#1173)
  * Use modern clang/libc++ for sanitizers (#1171)
  * Enable various sanitizer builds in github actions (#1167)
  * Random interleaving of benchmark repetitions - the sequel (fixes #1051) (#1163)
  * Fix leak in test, and provide path to remove leak from library (#1169)
  * [NFCI] Make BenchmarkRunner non-internal to it's .cpp file
  * [NFCI] RunBenchmarks(): extract FlushStreams()/Report() functions
  * compare.py: sort the results (#1168)
  * Make 'complexity reports' cache per-family, not global (#1166)
  * Introduce per-family instance index (#1165)
  * Introduce "family index" field into JSON output (#1164)
  * BenchmarkFamilies::FindBenchmarks(): correctly use std::vector<>::reserve()
  * Ensure that we print repetition count even when it was specified via flag `--benchmark_repetitions=`
  * Revert "Implementation of random interleaving.  (#1105)" (#1161)
  * Fix perf counter argument parsing (#1160)
  * Run build-and-test on all branches
  * Un-disable github actions :]
  * Run build-and-test on all branches
  * Set theme jekyll-theme-hacker
  * bump version to v1.5.4
  * Removing freenode from README
  * Fix pedantic compilation flag violation (#1156)
  * fix version recorded in releases (#1047)
  * Implementation of random interleaving.  (#1105)
  * remove appveyor and add libera.chat as IRC resource
  * [PFM] Extend perf counter support to multi-threaded cases. (#1153)
  * Support -Wsuggest-override (#1059)
  * Refactor `BenchmarkInstance` (#1148)
  * Remove travis configs that are covered by actions (#1145)
  * remove done TODOs
  * add g++-6 to ubuntu-14.04 (#1144)
  * Add MSVC ARM64 support to cmake (#1090)
  * Add ubuntu-14.04 build and test workflow (#1131)
  * Clean -Wreserved-identifier instances (#1143)
  * Fix StrSplit empty string case (#1142)
  * cmake: Add explicit BENCHMARK_ENABLE_LIBPFM option (#1141)
  * Add API to benchmark allowing for custom context to be added (#1137)
  * Add `benchmark_context` flag that allows per-run custom context. (#1127)
  * Add multiple compiler support to build-and-test workflow (#1128)
  * enable markdown rendering on github pages
  * Support optional, user-directed collection of performance counters (#1114)
* Wed Apr 28 2021 mpluskal@suse.com
- Update to version 1.5.3:
  * Be compliant and return 0 from main.
  * Fix windows warning on type conversion (#1121)
  * Add verbosity to CI logs (#1122)
  * fix cmake issue with referencing a non-existing function argument (#1118)
  * [tools] Fix dumb mistake in previous commit - print aggregates only means aggregates, not non-aggregates
  * [tools] Don't forget to print UTest when printing aggregates only
  * [sysinfo] Fix CPU Frequency reading on AMD Ryzen CPU's (#1117)
  * Use fewer ramp up repetitions when KeepRunningBatch is used (#1113)
  * Add bazel status to README
  * Re-enable bazel without bazelisk and with scoped build/test targets (#1109)
- Drop no longer needed 0001-src-benchmark_register.h-add-missing-limits-inclusio.patch
* Mon Feb  8 2021 Christophe Giboudeaux <christophe@krop.fr>
- Add upstream patch to fix build with GCC 11 (boo#1181865):
  * 0001-src-benchmark_register.h-add-missing-limits-inclusio.patch
* Tue Dec 29 2020 Martin Pluskal <mpluskal@suse.com>
- Update to version 1.5.2:
  * Timestamps in output are now rfc3339-formatted #965
  * overflow warnings with timers fixed #980
  * Python dependencies are now covered by a requirements.txt #994
  * JSON output cleaned up when no CPU scaling is present (#1008)
  * CartesianProduct added for easier settings of multiple ranges (#1029)
  * Python bindings improvements:
    + Custom main functions (#993)
    + A rename to google_benchmark (#199
    + More state methods bound (#1037) with a builder interface (#1040)
  * Workflow additions in github include pylint (#1039) and bindings runs (#1041)
* Mon Nov 18 2019 Simon Lees <sflees@suse.de>
- %%make_jobs is depricated replaced by %%cmake_build
* Thu Oct 17 2019 Richard Brown <rbrown@suse.com>
- Remove obsolete Groups tag (fate#326485)
* Mon Jun 24 2019 Martin Pluskal <mpluskal@suse.com>
- Update to version 1.5.0:
  * Bump CMake minimum version to 3.5.1 (see dependencies.md)
  * Add threads and repetitions to the JSON outputa
  * Memory management and reporting hooks
  * Documentation improvements
  * Miscellaneous build fixes
- Disable gtest part of tests untill new gtest is available
* Sat Feb 23 2019 Luigi Baldoni <aloisio@gmx.com>
- Use arch-specific libdir in pkgconfig file
* Mon Feb 18 2019 Luigi Baldoni <aloisio@gmx.com>
- Use arch-specific directories for support files
* Mon Jun 25 2018 mpluskal@suse.com
- Enable lto
- Update dependencies
* Mon May 28 2018 avindra@opensuse.org
- Update to version 1.4.1
  * Realign expectation that State::iterations() returns 0 before
    the main benchmark loop begins.
  * CMake error message fixes
  * Enscripten check fix
  * Bazel pthread linking
  * Negative regexes
  * gmock fix
* Wed Apr  4 2018 avindra@opensuse.org
- Update to version 1.4.0
  * Removal of deprecated headers
  * Improved CPU cache info reporting
  * Support State::KeepRunningBatch()
  * Support int64_t for AddRange()
  * New platform support: NetBSD, s390x, Solaris
  * Bazel build support
  * Support googletest unit tests
  * Add assembler tests
  * Various warnings fixed
- Drop benchmark-s390.patch
  * fixed upstream (commit ff2c255af5bb2fc2e5cd3b3685f0c6283117ce73)
* Tue Mar 27 2018 stefan.bruens@rwth-aachen.de
- Remove ExclusiveArch, it works on non-x86 as well
* Fri Mar 16 2018 avindra@opensuse.org
- Update to version 1.3.0:
  * Ranged for loop optimization!
  * Make installation optional
  * Better stats including user-provided ones
  * JSON reporter format fixes
  * Documentation improvements
- Includes changes from 1.2.0:
  * User-defined counters
  * Single header library
  * Ability to clear benchmarks so the runtime registration is more flexible
  * Sample-based standard deviation
  * 32-bit build enabled
  * Bug fixes
- Cleanup with spec-cleaner
- Use %%ctest macro for testing
* Fri Jan 27 2017 mpluskal@suse.com
- Update to version 1.1.0:
  * ArgNames support
  * Fixes for OSX and Cygwin and MSVC builds
  * PauseTiming and ResumeTiming are per thread (#286)
  * Better Range and Arg specifications
  * Complexity reporting
* Fri Jan 27 2017 bg@suse.com
- add support for s390x:
  * benchmark-s390.patch
* Sat Nov 12 2016 ro@suse.de
- add ExclusiveArch, package is not ported to anything but
  x86 and x86_64
* Mon Jul  4 2016 mpluskal@suse.com
- Disable lto as it does not seem to go well with -fPIE
* Sat May 14 2016 mpluskal@suse.com
- Initial package for version 1.0.0
